cgexplore.terms.Torsion
=======================

.. currentmodule:: cgexplore.terms

.. autoclass:: Torsion
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Torsion.atom_names
      ~Torsion.atom_ids
      ~Torsion.phi0
      ~Torsion.torsion_k
      ~Torsion.torsion_n
      ~Torsion.force
      ~Torsion.funct
   
   